@@ -18,7 +18,7 @@ st <- double(ncov)
 sd <- double(nvar)
 f.res <- .Fortran("int10",
 x=to.single(x),
-a=to.double(a),
+a=as.double(a),
 t=to.single(t),
 as.integer(exu()),
 as.integer(exup()),
@@ -38,11 +38,11 @@ tol=to.single(tol),
 xfud=to.single(xfud),
 nit=to.integer(nit),
 dist=to.single(dist),
-sa=to.double(sa),
-ss=to.double(ss),
-su=to.double(su),
-sup=to.double(sup),
-st=to.double(st),
-sd=to.double(sd))
+sa=as.double(sa),
+ss=as.double(ss),
+su=as.double(su),
+sup=as.double(sup),
+st=as.double(st),
+sd=as.double(sd))
 list(a=f.res$a,t=f.res$t,nit=f.res$nit,dist=f.res$dist)
 }
