@@ -2,7 +2,7 @@
 function(kode=1,x) {
 if (missing(x)) messagena("x")
 p <- double(1)
-f.res <- .Fortran("gaussd",
+f.res <- .Fortran("gausszd",
 kode=to.integer(kode),
 x=as.double(x),
 p=as.double(p))
