@@ -5,7 +5,7 @@ if (missing(ni)) messagena("ni")
 if (missing(a)) messagena("a")
 if (missing(e)) messagena("e")
 if (missing(t)) t <- single(1)
-f.res <- .Fortran("gycstp",
+f.res <- .Fortran("gycstpz",
 icase=to.integer(icase),
 ialg=to.integer(ialg),
 ni=to.integer(ni),
