@@ -3,7 +3,7 @@ function(alpha=.dFvGet()$alf,n) {
 if (missing(n)) messagena("n")
 k <- integer(1)
 alpha1 <- single(1)
-f.res <- .Fortran("liindh",
+f.res <- .Fortran("liindhz",
 alpha=to.single(alpha),
 n=to.integer(n),
 k=to.integer(k),
